diff --git a/.env.defaults b/.env.defaults
new file mode 100644
index 0000000000000000000000000000000000000000..c54467364023fe9ba11b643605873791013b2a5c
--- /dev/null
+++ b/.env.defaults
@@ -0,0 +1,21 @@
+# To override these variables, create a .env file containing the overrides.
+
+# The Janus backend to connect to. Used for all WebRTC traffic (realtime audio and networked data.)
+# See here for the server code: https://github.com/mozilla/janus-plugin-sfu
+JANUS_SERVER="wss://dev-janus.reticulum.io"
+
+# The Reticulum backend to connect to. Used for storing information about active hubs.
+# See here for the server code: https://github.com/mozilla/reticulum
+RETICULUM_SERVER="dev.reticulum.io"
+
+# The root URL under which Hubs expects environment GLTF bundles to be served.
+ASSET_BUNDLE_SERVER="https://asset-bundles-prod.reticulum.io"
+
+# The root URL under which Hubs expects static assets to be served.
+BASE_ASSETS_PATH=/
+
+# This origin trial token is used to enable WebVR in Android Chrome for hubs.mozilla.com.
+# You can find more information about getting your own origin trial token here:
+# https://github.com/GoogleChrome/OriginTrials/blob/gh-pages/developer-guide.md
+ORIGIN_TRIAL_TOKEN="AmTuFlYFGJ4KEbPVE20U0qoWZI3NZuaO8bjjcQvQI4OvDVC4Iyun5gkD8lwtNbrEzh617m5nig0+8QC+Pz6powYAAABVeyJvcmlnaW4iOiJodHRwczovL2h1YnMubW96aWxsYS5jb206NDQzIiwiZmVhdHVyZSI6IldlYlZSMS4xTTYyIiwiZXhwaXJ5IjoxNTM0ODg3ODE1fQ=="
+ORIGIN_TRIAL_EXPIRES="2018-08-21"
diff --git a/package.json b/package.json
index 631190d49cb0fdd1e75c4b566a84d91654de8ca2..5d8c7f777e5cd49102efb903ebc89c5c14f59b8e 100644
--- a/package.json
+++ b/package.json
@@ -13,7 +13,6 @@
     "url": "https://github.com/mozilla/hubs/issues"
   },
   "scripts": {
-    "postinstall": "node ./scripts/postinstall.js",
     "start": "webpack-dev-server --mode=development",
     "build": "rimraf ./dist && webpack --mode=production",
     "doc": "node ./scripts/doc/build.js",
diff --git a/scripts/default.env b/scripts/default.env
deleted file mode 100644
index c990e6272f69fc7e84dd08968f68a2a59d13b4d2..0000000000000000000000000000000000000000
--- a/scripts/default.env
+++ /dev/null
@@ -1,8 +0,0 @@
-# This origin trial token is used to enable WebVR and Gamepad Extensions on Chrome 62+
-# You can find more information about getting your own origin trial token here: https://github.com/GoogleChrome/OriginTrials/blob/gh-pages/developer-guide.md
-ORIGIN_TRIAL_TOKEN="AmTuFlYFGJ4KEbPVE20U0qoWZI3NZuaO8bjjcQvQI4OvDVC4Iyun5gkD8lwtNbrEzh617m5nig0+8QC+Pz6powYAAABVeyJvcmlnaW4iOiJodHRwczovL2h1YnMubW96aWxsYS5jb206NDQzIiwiZmVhdHVyZSI6IldlYlZSMS4xTTYyIiwiZXhwaXJ5IjoxNTM0ODg3ODE1fQ=="
-ORIGIN_TRIAL_EXPIRES="2018-08-21"
-JANUS_SERVER="wss://dev-janus.reticulum.io"
-RETICULUM_SERVER="dev.reticulum.io"
-ASSET_BUNDLE_SERVER="https://asset-bundles-prod.reticulum.io"
-BASE_ASSETS_PATH=/
diff --git a/scripts/hab-build-and-push.sh b/scripts/hab-build-and-push.sh
index bfe60faff8d3a59811fb0e9db07211f9b12433e8..48693732a8902bc487f72eb87e8ff27a02fa9af5 100755
--- a/scripts/hab-build-and-push.sh
+++ b/scripts/hab-build-and-push.sh
@@ -23,9 +23,6 @@ rm /usr/bin/env
 ln -s "$(hab pkg path core/coreutils)/bin/env" /usr/bin/env
 hab pkg install -b core/coreutils core/bash core/node core/git core/aws-cli
 
-# todo: consider more elegant ways to accomplish this
-cp scripts/default.env .env
-
 npm ci --verbose --no-progress
 npm run build
 mkdir dist/pages
diff --git a/scripts/postinstall.js b/scripts/postinstall.js
deleted file mode 100644
index 4d88d1a2654a946e73096ecf9be91ad8243c4b1b..0000000000000000000000000000000000000000
--- a/scripts/postinstall.js
+++ /dev/null
@@ -1,9 +0,0 @@
-const fs = require("fs");
-const path = require("path");
-
-const src = path.join(__dirname, "default.env");
-const dst = path.join(__dirname, "..", ".env");
-
-if (!fs.existsSync()) {
-  fs.copyFileSync(src, dst);
-}
diff --git a/webpack.config.js b/webpack.config.js
index add9a5aaea34f46708cff14ee534157ebdbf9168..75915b8f65c192b5245dcc897e7b96c5faa6566a 100644
--- a/webpack.config.js
+++ b/webpack.config.js
@@ -1,5 +1,7 @@
-// Variables in .env will be added to process.env
-require("dotenv").config();
+// Variables in .env and .env.defaults will be added to process.env
+const dotenv = require("dotenv");
+dotenv.config({ path: ".env" });
+dotenv.config({ path: ".env.defaults" });
 
 const fs = require("fs");
 const path = require("path");